@@ -7,7 +7,7 @@
 #'
 #' @param X an \eqn{(n\times p)} matrix or data frame whose rows are observations
 #' and columns represent independent variables.
-#' @param label a length-\eqn{n} vector of data class labels.
+#' @param label a length-\eqn{n} vector of data class labels. It should contain \code{NA} elements for missing label.
 #' @param ndim an integer-valued target dimension.
 #' @param type a vector of neighborhood graph construction. Following types are supported;
 #'  \code{c("knn",k)}, \code{c("enn",radius)}, and \code{c("proportion",ratio)}.
@@ -26,7 +26,7 @@
 #' }
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' ## generate data of 3 types with clear difference
 #' dt1  = aux.gensamples(n=33)-100
 #' dt2  = aux.gensamples(n=33)
@@ -48,10 +48,12 @@
 #' out3 = do.lsdf(X, label_missing, type=c("proportion",0.25))
 #'
 #' ## visualize
+#' opar <- par(no.readonly=TRUE)
 #' par(mfrow=c(1,3))
-#' plot(out1$Y[,1], out1$Y[,2], main="1% connectivity")
-#' plot(out2$Y[,1], out2$Y[,2], main="10% connectivity")
-#' plot(out3$Y[,1], out3$Y[,2], main="25% connectivity")
+#' plot(out1$Y, main="1% connectivity")
+#' plot(out2$Y, main="10% connectivity")
+#' plot(out3$Y, main="25% connectivity")
+#' par(opar)
 #' }
 #'
 #' @references
@@ -70,6 +72,9 @@ do.lsdf <- function(X, label, ndim=2, type=c("proportion",0.1),
   p = ncol(X)
   #   2. label : check and return a de-factored vector
   #   For this example, there should be no degenerate class of size 1.
+  if (missing(label)){
+    stop("* Semi-Supervised Learning : 'label' is required. For it not provided, consider using Unsupervised methods.")
+  }
   label  = check_label(label, n)
   ulabel = unique(label)
   if (all(!is.na(ulabel))){
