@@ -20,9 +20,11 @@
 #' }
 #'
 #' @examples
-#' \dontrun{
-#' ## generate samples
-#' X <- aux.gensamples(n=200, dname="crown")
+#' \donttest{
+#' ## use iris data
+#' data(iris)
+#' X     = as.matrix(iris[,1:4])
+#' label = as.integer(iris$Species)
 #'
 #' ## test different tolerance levels
 #' out1 <- do.spp(X,ndim=2,reltol=0.001)
@@ -30,10 +32,12 @@
 #' out3 <- do.spp(X,ndim=2,reltol=0.1)
 #'
 #' # visualize
+#' opar <- par(no.readonly=TRUE)
 #' par(mfrow=c(1,3))
-#' plot(out1$Y[,1], out1$Y[,2], main="reltol = 0.001")
-#' plot(out2$Y[,1], out2$Y[,2], main="reltol = 0.01")
-#' plot(out3$Y[,1], out3$Y[,2], main="reltol = 0.1")
+#' plot(out1$Y, col=label, main="SPP::reltol=.001")
+#' plot(out2$Y, col=label, main="SPP::reltol=.01")
+#' plot(out3$Y, col=label, main="SPP::reltol=.1")
+#' par(opar)
 #' }
 #' @references
 #' \insertRef{qiao_sparsity_2010}{Rdimtools}
@@ -104,7 +108,7 @@ spp_compute_si <- function(xi, Xi, reltol){
   n   = ncol(Xi)
   si  = CVXR::Variable(n)
   obj = CVXR::norm1(si)
-  constr = list(CVXR::p_norm(xi-(Xi%*%si),p=2)<reltol,(sum(si)==1))
+  constr = list(CVXR::p_norm(xi-(Xi%*%si),p=2)<=reltol,(sum(si)==1))
   prob = CVXR::Problem(Minimize(obj), constr)
   result = solve(prob)
   return(as.vector(result$getValue(si)))
