@@ -23,18 +23,22 @@
 #' IEEE Transactions on Computers, C-18 5:401-409.
 #'
 #' @examples
-#' \dontrun{
-#' ## generate default dataset
-#' ## in order to pass CRAN pretest, n is set to be small.
-#' X <- aux.gensamples(n=99)
+#' \donttest{
+#' ## load iris data
+#' data(iris)
+#' X     = as.matrix(iris[,1:4])
+#' label = as.factor(iris$Species)
 #'
 #' ## compare two initialization
 #' out1 = do.sammon(X,ndim=2)                   # random projection
 #' out2 = do.sammon(X,ndim=2,initialize="pca")  # pca as initialization
 #'
+#' ## visualize
+#' opar <- par(no.readonly=TRUE)
 #' par(mfrow=c(1,2))
-#' plot(out1$Y[,1],out1$Y[,2],main="out1:rndproj")
-#' plot(out2$Y[,1],out2$Y[,2],main="out2:pca")
+#' plot(out1$Y, col=label, main="out1:rndproj")
+#' plot(out2$Y, col=label, main="out2:pca")
+#' par(opar)
 #' }
 #'
 #' @references
@@ -45,7 +49,7 @@
 #' @author Kisung You
 #' @export
 do.sammon <- function(X,ndim=2,preprocess=c("null","center","scale","cscale","decorrelate","whiten"),
-                      initialize=c("random","pca")){
+                      initialize=c("pca","random")){
   # 1. typecheck is always first step to perform.
   aux.typecheck(X)
   if ((!is.numeric(ndim))||(ndim<1)||(ndim>ncol(X))||is.infinite(ndim)||is.na(ndim)){
