@@ -4,8 +4,6 @@
 #' that mimicks patterns of probability distributinos over pairs of high-dimensional objects on low-dimesional
 #' target embedding space by minimizing Kullback-Leibler divergence. While conventional SNE uses gaussian
 #' distributions to measure similarity, t-SNE, as its name suggests, exploits a heavy-tailed Student t-distribution.
-#' For \code{do.tsne}, we implemented a naive version of t-SNE as well as an interface with Barnes-Hut algorithm,
-#' which takes advantage of speed in sacrifice of accuracy.
 #'
 #' @param X an \eqn{(n\times p)} matrix or data frame whose rows are observations and columns represent independent variables.
 #' @param ndim an integer-valued target dimension.
@@ -21,8 +19,8 @@
 #' @param pcaratio proportion of variances explained in finding PCA preconditioning. See also \code{\link{do.pca}} for more details.
 #' @param pcascale a logical; \code{FALSE} for using Covariance, \code{TRUE} for using Correlation matrix. See also \code{\link{do.pca}} for more details.
 #' @param symmetric a logical; \code{FALSE} to solve it naively, and \code{TRUE} to adopt symmetrization scheme.
-#' @param BarnesHut a logical; \code{FALSE} not to use Barnes-Hut heuristic for faster computation, \code{TRUE} otherwise.
-#' @param BHtheta a positive real number for speed/accuracy trade-off in Barnes-Hut computation. See also \code{theta} parameter from \code{\link[Rtsne]{Rtsne}}.
+#' @param BHuse a logical; \code{TRUE} to use Barnes-Hut approximation. See \code{\link[Rtsne]{Rtsne}} for more details.
+#' @param BHtheta speed-accuracy tradeoff. If set as 0.0, it reduces to exact t-SNE.
 #'
 #' @return a named list containing
 #' \describe{
@@ -31,25 +29,29 @@
 #' }
 #'
 #' @examples
-#' \dontrun{
-#' ## generate swiss roll data
-#' X = aux.gensamples(n=100)
+#' \donttest{
+#' ## load iris data
+#' data(iris)
+#' X     = as.matrix(iris[,1:4])
+#' label = as.factor(iris$Species)
 #'
 #' ## compare different perplexity
 #' out1 <- do.tsne(X, ndim=2, perplexity=5)
 #' out2 <- do.tsne(X, ndim=2, perplexity=10)
-#' out3 <- do.tsne(X, ndim=2, perplexity=50)
+#' out3 <- do.tsne(X, ndim=2, perplexity=25)
 #'
 #' ## Visualize three different projections
+#' opar <- par(no.readonly=TRUE)
 #' par(mfrow=c(1,3))
-#' plot(out1$Y[,1], out1$Y[,2], main="tSNE::perplexity=5")
-#' plot(out1$Y[,1], out1$Y[,2], main="tSNE::perplexity=10")
-#' plot(out1$Y[,1], out1$Y[,2], main="tSNE::perplexity=50")
+#' plot(out1$Y, col=label, main="tSNE::perplexity=5")
+#' plot(out2$Y, col=label, main="tSNE::perplexity=10")
+#' plot(out3$Y, col=label, main="tSNE::perplexity=25")
+#' par(opar)
 #' }
 #'
-#' @seealso \code{\link{do.sne}}, \code{\link[Rtsne]{Rtsne}}.
+#' @seealso \code{\link{do.sne}}
 #' @references
-#' \insertRef{van_der_maaten_visualizing_2008}{Rdimtools}
+#' \insertRef{vandermaaten_visualizing_2008}{Rdimtools}
 #'
 #' @author Kisung You
 #' @rdname nonlinear_TSNE
@@ -58,7 +60,7 @@ do.tsne <- function(X,ndim=2,perplexity=30,eta=0.05,maxiter=2000,
                     jitter=0.3,jitterdecay=0.99,momentum=0.5,
                     preprocess=c("null","center","scale","cscale","decorrelate","whiten"),
                     pca=TRUE,pcaratio=0.90,pcascale=FALSE,symmetric=FALSE,
-                    BarnesHut=FALSE,BHtheta=0.5){
+                    BHuse=TRUE, BHtheta=0.25){
   # 1. typecheck is always first step to perform.
   aux.typecheck(X)
   #   1-1. (integer) ndim
@@ -74,7 +76,9 @@ do.tsne <- function(X,ndim=2,perplexity=30,eta=0.05,maxiter=2000,
     message("* do.tsne : a desired perplexity value is in [5,50].")
   }
 
-
+  # obsolete params.
+  BarnesHut=as.logical(BHuse)
+  BHtheta=as.double(BHtheta)
   # 2. Input Parameters
   #   2-1. (double) eta = 0.5; learning parameter
   if (!is.numeric(eta)||is.na(eta)||is.infinite(eta)||(eta<=0)){
@@ -147,11 +151,16 @@ do.tsne <- function(X,ndim=2,perplexity=30,eta=0.05,maxiter=2000,
 
     Y = t(as.matrix(method_tsne(P,ndim,eta,maxiter,jitter,decay,momentum)))
   } else {
-    pX = t(tpX)
-    out = Rtsne(pX,dims=ndim,theta=BHtheta,perplexity=perplexity,pca=TRUE,max_iter=maxiter,
+    pX   = t(tpX)
+    dX   = stats::dist(pX)
+    dfun = utils::getFromNamespace("hidden_tsne","maotai")
+    out  = dfun(dX, ndim=round(ndim),theta=BHtheta,perplexity=perplexity,pca=FALSE,max_iter=maxiter,
                 momentum=momentum,eta=eta)
-    Y = (out$Y)
+    # out = Rtsne(pX,dims=ndim,theta=BHtheta,perplexity=perplexity,pca=TRUE,max_iter=maxiter,
+    #             momentum=momentum,eta=eta)
+    Y = out$embed
   }
+
   # 5. result
   if (any(is.infinite(Y))||any(is.na(Y))){
     message("* do.tsne : t-SNE not successful; having either Inf or NA values.")
