@@ -5,17 +5,20 @@
   date <- date()
   x <- regexpr("[0-9]{4}", date)
   this.year <- substr(date, x[1], x[1] + attr(x, "match.length") - 1)
-  
+
   # Retrieve Current Version
   this.version = packageVersion("Rdimtools")
-  
+
   ## Print on Screen
+  packageStartupMessage("** ------------------------------------------------------- **")
   packageStartupMessage("** Rdimtools")
   packageStartupMessage("**  - Dimension Reduction and Estimation Toolbox")
-  packageStartupMessage("** Version    : ",this.version," (",this.year,")",sep="")
-  packageStartupMessage("** Maintainer : Kisung You (kyou@nd.edu)")
+  packageStartupMessage("**")
+  packageStartupMessage("** Version    : ",this.version,"      (",this.year,")",sep="")
+  packageStartupMessage("** Maintainer : Kisung You (kyoustat@gmail.com)")
   packageStartupMessage("**")
   packageStartupMessage("** Please share any bugs or suggestions to the maintainer.")
+  packageStartupMessage("** ------------------------------------------------------- **")
 }
 
 .onUnload <- function(libpath) {
